@@ -12,7 +12,8 @@ from django.template.loader import render_to_string
 from django.utils.html import strip_tags
 import re
 
-job_fields = ["@id", "author", "title", "description", "creationDate", "skills", "budget", "duration", "earnBusinessProviding", "closingDate", "conversation"]
+job_fields = ["@id", "author", "title", "description", "creationDate", "skills", "budget", "duration", "location",\
+    "earnBusinessProviding", "closingDate", "conversation"]
 if 'djangoldp_community' in settings.DJANGOLDP_PACKAGES:
     job_fields += ['community']
 
@@ -24,6 +25,7 @@ class JobOffer(Model):
     duration = models.CharField(max_length=255, blank=True, null=True)
     budget = models.CharField(max_length=255, blank=True, null=True)
     earnBusinessProviding = models.BooleanField(default=False)
+    location = models.CharField(max_length=255, blank=True, null=True)
     skills = models.ManyToManyField(Skill, blank=True)
     creationDate = models.DateTimeField(auto_now_add=True)
     closingDate = models.DateField(null=True)
